aboutsummaryrefslogtreecommitdiffstats
path: root/include/llvm/Function.h
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2005-01-29 18:41:00 +0000
committerChris Lattner <sabre@nondot.org>2005-01-29 18:41:00 +0000
commit38653f0ac83b793142cd0f3000ba5b1667b08a80 (patch)
treef31f2acabf80c26fdad3d93a75827fc4e4ec2316 /include/llvm/Function.h
parented4d467c690b549f2cc9721abcc0dbb07291678f (diff)
downloadexternal_llvm-38653f0ac83b793142cd0f3000ba5b1667b08a80.zip
external_llvm-38653f0ac83b793142cd0f3000ba5b1667b08a80.tar.gz
external_llvm-38653f0ac83b793142cd0f3000ba5b1667b08a80.tar.bz2
Adjust to changes in ilist
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@19922 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/Function.h')
-rw-r--r--include/llvm/Function.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/include/llvm/Function.h b/include/llvm/Function.h
index a4545a7..88d7d34 100644
--- a/include/llvm/Function.h
+++ b/include/llvm/Function.h
@@ -31,17 +31,18 @@ class FunctionType;
template<> struct ilist_traits<BasicBlock>
: public SymbolTableListTraits<BasicBlock, Function, Function> {
- // createNode is used to create a node that marks the end of the list...
- static BasicBlock *createNode();
-
+ // createSentinal is used to create a node that marks the end of the list...
+ static BasicBlock *createSentinal();
+ static void destroySentinal(BasicBlock *BB) { delete BB; }
static iplist<BasicBlock> &getList(Function *F);
};
template<> struct ilist_traits<Argument>
: public SymbolTableListTraits<Argument, Function, Function> {
- // createNode is used to create a node that marks the end of the list...
- static Argument *createNode();
+ // createSentinal is used to create a node that marks the end of the list...
+ static Argument *createSentinal();
+ static void destroySentinal(Argument *A) { delete A; }
static iplist<Argument> &getList(Function *F);
};